package fr.cnam.projet;

import java.util.*;
import java.text.*;

import fr.cnam.util.*;

// Classe de definition d'un agenda
//
// Un agenda gère une liste de RendezVous :
//    - lors de la creation de l'agenda (constructeur), la liste de rdv est
//      initialisee avec un fichier texte contenant les rdvs
//    - il est ensuite possible via l'IHM d'ajouter un nouveau rendez-vous
//
// Cet agenda est utilise a partir de l'ihm IHMAgenda afin de pouvoir afficher
//   les rendez-vous dans l'IHM
//
public class Agenda
{
    private ArrayList<RendezVous> elements;  // La liste des rendez-vous

    private String dateCourante;             /* Date courante d'affichage des rdvs
                                                d'un jour donné */


    private int compteur;  // compteur interne
    // Ce compteur est utilise pour numeroter les rendez-vous qui sont
    //  ajoutes dans l'agenda. Ce numero permet de supprimer un rendez-vous
    //  en precisant son numero.
    //

    // Constructeur
    //
    public Agenda(String nomFichier)
    {
        // Creation de la liste des rendez-vous
        elements = new ArrayList<RendezVous>();

        // Initialisation du compteur
        compteur = 1;

        // lecture du fichier contenant :
        //    - en 1ere ligne : la date courante initiale
        //    - les autres lignes : 1 rdv par ligne
        //

        // On recupere toutes les lignes du fichier
        String[] lignes = Terminal.lireFichierTexte(nomFichier);

        //Initialisation de la date courante
        //
        // La date courante change a chaque passage a la date suivante ou
        //  precedente
        //
        dateCourante = lignes[0];
        
        //Les autres lignes : les rendez-vous
        //  Pour chaque ligne on va decoder la ligne puis ajouter
        //   le rdv ainsi decoder dans la liste
        //
        for(int i=1;i<lignes.length;i++)
            {
                // Decodage de la ligne
                String ligne = lignes[i];
                System.out.println(ligne); // Pour vérifier
                String[] champs = ligne.split("[;]");
                String com;
                // Si le commentaire est vide alors il y a que 4 champs
                if (champs.length==4) com = "";
                else com = champs[4];

                //Ajout du rendez-vous dans la collection
                //
                ajouterRdv(champs[0],
                           champs[1],
                           champs[2],
                           champs[3],
                           com);
            }
        
    }

    // Methode qui cree et ajoute un rendez-vous dans la collection
    //
    public void ajouterRdv(String date,
                           String heure_debut,
                           String heure_fin,
                           String texte,
                           String commentaire)
    {
        // Creation du rdv
        RendezVous rdv = new RendezVous(compteur,
                                        date,
                                        heure_debut,
                                        heure_fin,
                                        texte,
                                        commentaire);
        // Ajout du rdv
        elements.add(rdv);

        // On incremente le compteur pour le prochain rdv
        //   qui sera cree
        compteur = compteur + 1;

    }
    
    // Methode qui retourne sous la forme d'une chaine de caractère
    //  tous les rendez-vous de l'agenda
    //
    public String getTousRendezVous()
    {
        String res="";

        for(RendezVous rdv : elements)
            res=res+rdv.toString()+"\n--------------------\n";
        return res;
    }

    // Methode qui retourne sous la forme d'une chaine de caractère
    //  tous les rendez-vous de l'agenda qui appartiennent 
    //  à la date passe en parametre
    //
    public String getDateRendezVous(String dateRdv)
    {
        if (! siDateCorrect(dateRdv))
            return "La date saisie est incorrecte";

        // On cree une liste temporaire qui contiendra les
        //  rendez-vous appartenant à cette date
        ArrayList<RendezVous> rdvTmp = new ArrayList<RendezVous>();

        // On parcourt tous les rendez-vous et on ne garde que ceux
        //  qui correspondent à la date ou qui n'ont pas de date
        //
        for(RendezVous rdv : elements)
            switch (rdv.getType())
                {
                    // On garde un rdv normal si sa date est egale
                    //  a celle donnee
                case RendezVous.RDV_NORMAL :
                    {
                        if (rdv.getDate().equals(dateRdv))
                            rdvTmp.add(rdv);
                        break;
                    }
                    // On garde systematiquement le rdv qui est une note
                    //  ou qui est tous les jours
                case RendezVous.RDV_NOTE :
                case RendezVous.RDV_QUOTIDIEN :
                    {
                        rdvTmp.add(rdv);
                        break;
                    }
                    // On garde un rdv hebdo si la date donnee n'est
                    //  pas un samedi ou un dimanche
                case RendezVous.RDV_HEBDO :
                    {
                        if (! siSamediOuDimanche(dateRdv))
                            rdvTmp.add(rdv);
                        break;
                    }
                }//Switch
        
        // On trie la liste temporaire en fonction de l'heure
        trierHoraire(rdvTmp);

        // On retourne cette liste sous la forme d'une chaine
        //  de caractère sur une seule ligne
        String res="========= "+dateRdv+" ===============\n";
        for(RendezVous rdv : rdvTmp)
            res=res+rdv.toStringHoraire()+"\n";
        return res;
    }

    // Methode qui supprime un rendez-vous en fonction de son numero
    //
    public String supprimerRdv(int numero)
    {
        // On recherche le numero dans les rdvs
        for(int i=0;i<elements.size();i++)
            if (elements.get(i).getNumero()==numero)
                {
                    // Suppression du rendez-vous
                    elements.remove(i);
                    // On affiche les rdv de la date courante
                    return getDateRendezVous(dateCourante);
                }
        // Si non trouve alors on retourne un texte d'erreur
        return "rdv numero="+numero+" non trouve. Pas de suppression";
    }

    // Retourne la date courante
    //
    public String getDateCourante()
    {
        return dateCourante;
    }

    // Methode qui change la date courante avec la date precedente
    //
    public void datePrecedente()
    {
        SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
        Date d = sdf.parse(this.dateCourante,
                           new ParsePosition(0));
        Calendar dateCal = Calendar.getInstance();
        dateCal.setTime(d);

        dateCal.set(Calendar.SECOND,-86400);

        sdf = new SimpleDateFormat("dd/MM/yyyy");
        StringBuffer sb = new StringBuffer();
        sdf.format(dateCal.getTime(),sb,new FieldPosition(0));
        
        dateCourante = sb.toString();
    }

    // Methode qui change la date courante avec la date suivante
    //
    public void dateSuivante()
    {
        SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
        Date d = sdf.parse(this.dateCourante,
                           new ParsePosition(0));
        Calendar dateCal = Calendar.getInstance();
        dateCal.setTime(d);

        dateCal.set(Calendar.SECOND,86400);

        sdf = new SimpleDateFormat("dd/MM/yyyy");
        StringBuffer sb = new StringBuffer();
        sdf.format(dateCal.getTime(),sb,new FieldPosition(0));
        
        dateCourante = sb.toString();
    }

    // Methode qui trie par ordre croissant sur l'heure de debut les rendez-vous
    //  de la liste passe en parametre
    //
    public static void trierHoraire(ArrayList<RendezVous> listeRdv)
    {
        if (listeRdv.size()<=1) return;

        // Algo de tri à bulle
        boolean swap=true;
        while (swap)
            {
                swap=false;
                for(int i=0;i<listeRdv.size()-1;i++)
                    {
                        String heure1 = listeRdv.get(i).getHeureDebut();
                        String heure2 = listeRdv.get(i+1).getHeureDebut();
                        if (heure(heure1)>heure(heure2))
                            {
                                swap=true;
                                RendezVous tmp = listeRdv.get(i);
                                listeRdv.set(i,listeRdv.get(i+1));
                                listeRdv.set(i+1,tmp);
                            }
                    }
            }
    }

    // Methode qui convertit en secondes une heure ecrite en "HH:mm"
    //
    public static int heure(String heure)
    {
        if (heure.equals("")) return 0;
        String[] elts = heure.split(":");
        int h = Integer.parseInt(elts[0]);
        int mn = Integer.parseInt(elts[1]);
        return h*60+mn;
    }

    // Methode qui teste si une date passee en parametre
    //  est un samedi ou un dimanche
    //
    public static boolean siSamediOuDimanche(String date)
    {
        SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
        Date d = sdf.parse(date,
                           new ParsePosition(0));
        Calendar dateCal = Calendar.getInstance();
        dateCal.setTime(d);

        int day = dateCal.get(Calendar.DAY_OF_WEEK);
        if ( (day==Calendar.SATURDAY) ||
             (day==Calendar.SUNDAY) )
            return true;
        return false;
    }

    //Setteut sur la date courante
    //
    public void setDateCourante(String date)
    {this.dateCourante=date;}

    // Methode static qui verifie si le format de saisie HH:MM
    //  est correct
    //
    public static boolean siHeureCorrect(String heureMinute)
    {
        if (heureMinute.equals("")) return true;

        char t[] = heureMinute.toCharArray();
        if (t.length != 5) return false;
        char h1=t[0];
        char h2=t[1];
        char sep=t[2];
        char m1=t[3];
        char m2=t[4];
        
        if (! Character.isDigit(h1)) return false;
        if (! Character.isDigit(h2)) return false;
        if (sep!=':') return false;
        if (! Character.isDigit(m1)) return false;
        if (! Character.isDigit(m2)) return false;
        
        int heure  = Integer.parseInt(""+h1+h2);
        int minute = Integer.parseInt(""+m1+m2);
        
        if (heure>23) return false;
        if (minute>59) return false;

        return true;
    }

    // Methode static qui verifie si le format JJ/MM/AAAA est correct
    //
    public static boolean siDateCorrect(String date)
    {
        if (date.equals("")) return true;

        char t[] = date.toCharArray();
        if (t.length != 10) return false;

        for(int i=0;i<10;i++)
            {
                if ((i==2)||(i==5)) continue;
                if (!Character.isDigit(t[i])) return false;
            }
        char sep1=t[2];
        char sep2=t[5];
        if ((t[2]!='/')||(t[5]!='/')) return false;

        int jour  = Integer.parseInt(""+t[0]+t[1]);
        int mois  = Integer.parseInt(""+t[3]+t[4]);
        int annee = Integer.parseInt(""+t[6]+t[7]+t[8]+t[9]);
        
        if ((jour==0)||(jour>31)) return false;
        if ((mois==0)||(mois>12)) return false;
        
        return true;
    }

    // Methode staic qui verifie si le numero saisi est correct
    //
    public static boolean siNumeroCorrect(String numero)
    {
        if (numero.equals("")) return false;

        char t[] = numero.toCharArray();
        for(int i=0;i<t.length;i++)
            if (!Character.isDigit(t[i])) return false;
        return true;
    }

}