package fr.cnam.projet;

import java.util.*;

import fr.cnam.ihm.*;

// Classe de definition de l'IHM permettant de gerer un agenda
//   Elle implémente l'interface FormulaireInt permettant
//    d'executer du code quand on clique sur un bouton de l'IHM
//
public class IHMAgenda implements FormulaireInt
{
    private Agenda     agenda;  // L'agenda
    private Formulaire form;    // Le formulaire

    // Constructeur
    //
    public IHMAgenda(Agenda agenda)
    {
        this.agenda = agenda;

        // Creation du formulaire
        form = new Formulaire("Exemple",this,830,530);
        
        //  Creation des elements de l'IHM
        //
        form.addLabel("Afficher tous les rendez-vous");
        form.addButton("AFF_TOUT_AGENDA","Tout");
        form.addLabel("Afficher les rendez-vous d'une date");
        form.addText("DATE","Date",true,agenda.getDateCourante());
        form.addButton("AFF_DATE_AGENDA","Valider");
        form.addLabel("");

        String dc = agenda.getDateCourante();
        form.addText("DATE_COUR","Date courante",false,dc);
        form.addButton("PREC","PREC");
        form.addButton("COUR","COUR");
        form.addButton("SUIV","SUIV");
        form.addLabel("");
        form.addButton("AJOUTER","Ajouter un rdv");
        form.addLabel("");
        form.addText("NUMERO","Numero du rdv",true,"");
        form.addButton("SUPPRIMER","Supprimer un rdv");

        form.setPosition(300,0);
        form.addZoneText("RESULTATS","Resultats",
                            true,
                            "",
                            500,500);

        // Affichage du formulaire
        form.afficher();
    }

    // Methode appellee quand on clique dans un bouton
    //
    public void submit(Formulaire form,String nomSubmit)
    {

        // Affichage de tous les rendez-vous de l'agenda
        //
        if (nomSubmit.equals("AFF_TOUT_AGENDA"))
            {
                String res = agenda.getTousRendezVous();
                form.setValeurChamp("RESULTATS",res);
            }

        // Affichage de tous les rendez-vous d'une date donnée
        //
        if (nomSubmit.equals("AFF_DATE_AGENDA"))
            {
                String date = form.getValeurChamp("DATE");
                if (date.equals("")) 
                    form.setValeurChamp("RESULTATS","Saisisez une date");
                else
                    {
                        String res = agenda.getDateRendezVous(date);
                        form.setValeurChamp("DATE_COUR",date);
                        agenda.setDateCourante(date);
                        afficherRdvsDateCourante();
                    }
            }

        // Affiche les rdvs de la date courante
        //
        if (nomSubmit.equals("COUR"))
            {
                String dateCour = agenda.getDateCourante();
                form.setValeurChamp("DATE_COUR",dateCour);

                afficherRdvsDateCourante();
            }

        // Passer au jour precedent
        //
        if (nomSubmit.equals("PREC"))
            {
                // la date courante de l'agenda passe a la date precedente
                agenda.datePrecedente();
                form.setValeurChamp("DATE_COUR",agenda.getDateCourante());

                // On affiche les rdvs de la date courante
                afficherRdvsDateCourante();
            }

        // Passer au jour suivant
        //
        if (nomSubmit.equals("SUIV"))
            {
                // la date courante de l'agenda passe a la date suivante
                agenda.dateSuivante();
                form.setValeurChamp("DATE_COUR",agenda.getDateCourante());

                // On affiche les rdvs de la date courante
                afficherRdvsDateCourante();
            }

        // Ajouter un nouveau rendez-vous
        //
        if (nomSubmit.equals("AJOUTER"))
            {
                // Creation de l'ihm qui permet de saisir un nouveau rdv
                IHMAjouterRendezVous ihm = new IHMAjouterRendezVous(agenda,this);
            }

        // Supprimer un rendez-vous
        //
        if (nomSubmit.equals("SUPPRIMER"))
            {
                String res;
                String snum = form.getValeurChamp("NUMERO");
                if (! Agenda.siNumeroCorrect(snum))
                    res = "Veuillez saisir un numero";
                else
                    {
                        int num = Integer.parseInt(snum);
                        res = "Le rdv numero="+snum+" a ete supprime";
                    }
                form.setValeurChamp("RESULTATS",res);
            }
    }
    
    // Cette methode permet a l'IHM d'ajout d'un rdv d'afficher
    //   un texte dans la zone resultat
    //
    public void afficherResultat(String res)
    {
        form.setValeurChamp("RESULTATS",res);
    }

    // Affiche les rdvs de la date courante
    //
    public void afficherRdvsDateCourante()
    {
        String dateCour = agenda.getDateCourante();
        String res = agenda.getDateRendezVous(dateCour);
        form.setValeurChamp("RESULTATS",res);
    }
}