package fr.cnam.projet;

import java.util.*;

import fr.cnam.ihm.*;

// Classe de definition de l'IHM permettant d'ajouter un rdv
//   Elle implémente l'interface FormulaireInt permettant
//    d'executer du code quand on clique sur un bouton de l'IHM
//
public class IHMAjouterRendezVous implements FormulaireInt
{
    private Agenda agenda;        /* L'agenda (pour appeler un traitement
                                     de l'agenda sur clic bouton) */
    private IHMAgenda ihmAgenda;  /* Ihm de l'agenda (pour afficher un texte
                                     dans la zone resultat */

    // Constructeur
    //
    public IHMAjouterRendezVous(Agenda agenda,IHMAgenda ihmAgenda)
    {
        this.agenda    = agenda;
        this.ihmAgenda = ihmAgenda;

        // Creation du formulaire
        Formulaire form = new Formulaire("Exemple",this,250,400);
        
        //  Creation des elements de l'IHM
        //  -----

        // les champs de saisi d'un rdv
        //
        String dc = agenda.getDateCourante();
        form.addText("DATE","Date",true,dc);
        form.addText("HEURE_DEBUT","Heure debut",true,"");
        form.addText("HEURE_FIN","Heure fin",true,"");
        form.addText("TEXTE","Texte",true,"");
        form.addText("COMM","Commentaire",true,"");

        // les boutons de validation et d'annulation
        //
        form.addButton("VALIDER","Valider");
        form.addButton("ANNULER","Annuler");

        // Position de la fenetre
        //
        form.setPosition(300,300);

        // Affichage du formulaire
        form.afficher();
    }

    // Methode appellee quand on clique dans un bouton
    //
    public void submit(Formulaire form,String nomSubmit)
    {

        // Valider le formulaire de saisi d'un rdv
        //
        if (nomSubmit.equals("VALIDER"))
            {
                // Recuparation des informations
                //
                String date        = form.getValeurChamp("DATE");
                String heure_debut = form.getValeurChamp("HEURE_DEBUT");
                String heure_fin   = form.getValeurChamp("HEURE_FIN");
                String texte       = form.getValeurChamp("TEXTE");
                String commentaire = form.getValeurChamp("COMM");
                
                // Si le texte du rendez vous est vide alors 
                //    afficher une erreur
                //
                if (texte.equals(""))
                    ihmAgenda.afficherResultat("Erreur: le champ texte est vide");
                else if (! Agenda.siDateCorrect(date))
                    ihmAgenda.afficherResultat("Erreur: la date est incorrecte");
                else if (! Agenda.siHeureCorrect(heure_debut))
                    ihmAgenda.afficherResultat("Erreur: l'heure de debut est incorrect");
                else if (! Agenda.siHeureCorrect(heure_fin))
                    ihmAgenda.afficherResultat("Erreur: l'heure de fin est incorrect");
                else
                    {
                        // Ajouter un rdv dans l'agenda
                        //
                        agenda.ajouterRdv(date,
                                          heure_debut,
                                          heure_fin,
                                          texte,
                                          commentaire);
                        form.fermer();
                        ihmAgenda.afficherRdvsDateCourante();
                    }
            }

        // Annuler : on ferme la fenetre
        //
        if (nomSubmit.equals("ANNULER"))
            {
                ihmAgenda.afficherResultat("Annulation de l'ajout d'un rdv");
                form.fermer();
            }
    }

}