package fr.cnam.projet;

import java.util.*;
import java.text.*;

// Classe de definition d'un rendez-vous
//
public class RendezVous
{
    // Les caracteristiques d'un rendez-vous
    //
    private int    numero;         // numero du rendez-vous
    private String date;           // date du rdv
    private String heure_debut;    // heure de debut
    private String heure_fin;      // heure de fin
    private String libelle;        // nom du rdv
    private String commentaire;    // commentaire du rdv
    //
    // Remarque : Le numero interne d'un rendez-vous permet d'identifier de
    //  maniere unique un rendez-vous.
    //

    // Les differents type de rendez-vous
    //
    // RDV_NORMAL    : rdv qui a une date et une heure de debut
    // RDV_QUOTIDIEN : un rdv qui est tous les jours avec une heure debut
    // RDV_HEBDO     : un rdv qui est tous les jours sauf le week-end
    // RDV_NOTE      :  un "rdv" qui n'a pas de date ni d'heure
    //
    private int type;
    final public static int RDV_NORMAL=0;
    final public static int RDV_QUOTIDIEN=1;
    final public static int RDV_HEBDO=2;
    final public static int RDV_NOTE=3;


    // Constructeur
    //
    public RendezVous(int compteur,
                      String date,
                      String heure_debut,
                      String heure_fin,
                      String libelle,
                      String commentaire)
    {
        //Initialisation des caracteristiques du rendez-vous
        this.numero      = compteur;
        this.date        = date;
        this.heure_debut = heure_debut;
        this.heure_fin   = heure_fin;
        this.libelle     = libelle;
        this.commentaire = commentaire;
        

        // Initilisation du type de rendez-vous en fonction
        //   de la date et de l'heure

        // Rdv avec une date et une heure
        //
        if ( (! this.date.equals("")) && 
             (! this.date.equals("hebdo")) && 
             (! this.heure_debut.equals("")) )
            {
                this.type = RDV_NORMAL;
            }

        // Rdv sans date et sans heure
        //
        else if ( (this.date.equals("")) && 
                  (this.heure_debut.equals("")) )
            {
                this.type = RDV_NOTE;
            }
        
        // Rdv sans date mais avec une heure
        //
        else if ( (date.equals("")) &&
                  (! heure_debut.equals("")) )
            {
                this.type = RDV_QUOTIDIEN;
            }

        // Rdv hebdo
        //
        else if ( (this.date.equals("hebdo")) && 
                  (! this.heure_debut.equals("")) )
            {
                this.type = RDV_HEBDO;
            }

    }
    
    // Un rendez-vous sous la forme d'une chaine de caractere
    //  qui affiche tous les attributs d'un rendez-vous
    //
    public String toString()
    {
        return 
            "numero : "+numero+"\n"+
            "date   : "+date+"\n"+
            "debut  : "+heure_debut+"\n"+
            "fin    : "+heure_fin+"\n"+
            "texte  : "+libelle+"\n"+
            "comm   : "+commentaire;
    }

    // Un rendez-vous sous la forme d'une ligne utilise dans
    //  l'affichage des rendez-vous d'une date donnee
    // Le format est :
    //    <numero> : <heure> : <texte> : <commentaire>
    //
    public String toStringHoraire()
    {
        return
            String.format("%03d : %5s : %30s : %s",
                      numero,heure_debut,libelle,commentaire);
    }

    // getteurs et setteurs
    //
    public String getDate()    {return date;}
    public int getType()    {return type;}
    public int getNumero()    {return numero;}
    public String getHeureDebut(){ return heure_debut;}
}

    